@@ -9,12 +9,12 @@ __title__ = "skinport"
 __author__ = "PaxxPatriot"
 __license__ = "MIT"
 __copyright__ = "Copyright 2022 PaxxPatriot"
-__version__ = "0.2.2"
+__version__ = "0.3.0"
 
 __path__ = __import__("pkgutil").extend_path(__path__, __name__)
 
 import logging
-from typing import NamedTuple, Literal
+from typing import NamedTuple
 
 from .client import *
 from .enums import *
@@ -29,12 +29,10 @@ class VersionInfo(NamedTuple):
     major: int
     minor: int
     micro: int
-    releaselevel: Literal["alpha", "beta", "candidate", "final"]
+    releaselevel: str
     serial: int
 
 
-version_info: VersionInfo = VersionInfo(
-    major=0, minor=2, micro=2, releaselevel="final", serial=0
-)
+version_info: VersionInfo = VersionInfo(major=0, minor=3, micro=0, releaselevel="final", serial=0)
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
